pyinaturalist.models
====================
.. automodule:: pyinaturalist.models

.. automodsumm:: pyinaturalist.models
    :classes-only:
    :nosignatures:
    :skip: BaseModel, BaseModelCollection, LazyProperty
